@@ -666,13 +666,15 @@ def test_fail():
     result.stdout.fnmatch_lines(['*1 failed*'])
 
 
-def test_no_cov(testdir):
+def test_no_cov(testdir, monkeypatch):
     script = testdir.makepyfile(SCRIPT)
-
+    testdir.makeini("""
+        [pytest]
+        addopts=--no-cov
+    """)
     result = testdir.runpytest('-vvv',
                                '--cov=%s' % script.dirpath(),
                                '--cov-report=term-missing',
-                               '--no-cov',
                                '-rw',
                                script)
     result.stdout.fnmatch_lines_random([
@@ -2009,8 +2011,10 @@ def test_cov_and_no_cov(testdir):
     result = testdir.runpytest('-v',
                                '--cov', '--no-cov',
                                '-n', '1',
+                               '-s',
                                script)
-
+    assert 'Coverage disabled via --no-cov switch!' not in result.stdout.str()
+    assert 'Coverage disabled via --no-cov switch!' not in result.stderr.str()
     assert result.ret == 0
 
 
